==> jc-1.4.0.tar.gz: gnu/java/security/provider/GnuDHPublicKey.h <==
// public class gnu.java.security.provider.GnuDHPublicKey

// class file dependencies
// @dep_class 626eb7f000fcea34 gnu_java_security_provider_GnuDHPublicKey
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_GnuDHPublicKey_H_
#define _JC_gnu_java_security_provider_GnuDHPublicKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_javax_crypto_spec_DHParameterSpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$sub_refs	_jc_gnu_java_security_provider_GnuDHPublicKey$sub_refs;
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$sub_nonrefs	_jc_gnu_java_security_provider_GnuDHPublicKey$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$refs	_jc_gnu_java_security_provider_GnuDHPublicKey$refs;
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$nonrefs	_jc_gnu_java_security_provider_GnuDHPublicKey$nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$object	_jc_gnu_java_security_provider_GnuDHPublicKey$object;

typedef const struct _jc_gnu_java_security_provider_GnuDHPublicKey$vmethods	_jc_gnu_java_security_provider_GnuDHPublicKey$vmethods;
typedef const struct _jc_gnu_java_security_provider_GnuDHPublicKey$vtable	_jc_gnu_java_security_provider_GnuDHPublicKey$vtable;
typedef const struct _jc_gnu_java_security_provider_GnuDHPublicKey$vtype	_jc_gnu_java_security_provider_GnuDHPublicKey$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_GnuDHPublicKey$method$_init$7107c3e523ee96ea(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *, struct _jc_javax_crypto_spec_DHParameterSpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);
extern _jc_byte_array *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);
extern struct _jc_javax_crypto_spec_DHParameterSpec$object *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getParams$ce54829b76ac0d04(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getY$e067a5f1fb934d2a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getParams$ce54829b76ac0d04;
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getY$e067a5f1fb934d2a;

// Virtual methods structure
struct _jc_gnu_java_security_provider_GnuDHPublicKey$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);
	struct _jc_javax_crypto_spec_DHParameterSpec$object	*(*getParams$ce54829b76ac0d04)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);
	struct _jc_java_math_BigInteger$object	*(*getY$e067a5f1fb934d2a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_GnuDHPublicKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_GnuDHPublicKey$vmethods	gnu_java_security_provider_GnuDHPublicKey;
};

// Vtype
struct _jc_gnu_java_security_provider_GnuDHPublicKey$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_GnuDHPublicKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDHPublicKey$sub_refs {
	_jc_byte_array	*encoded;
	struct _jc_javax_crypto_spec_DHParameterSpec$object	*params;
	struct _jc_java_math_BigInteger$object	*Y;
	struct _jc_java_math_BigInteger$object	*q;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDHPublicKey$refs {
    _jc_gnu_java_security_provider_GnuDHPublicKey$sub_refs	gnu_java_security_provider_GnuDHPublicKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDHPublicKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDHPublicKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_GnuDHPublicKey$sub_nonrefs	gnu_java_security_provider_GnuDHPublicKey;
};

// Object instance structure
struct _jc_gnu_java_security_provider_GnuDHPublicKey$object {
	_jc_gnu_java_security_provider_GnuDHPublicKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_GnuDHPublicKey$vtype	*vtype;
	_jc_gnu_java_security_provider_GnuDHPublicKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_GnuDHPublicKey$vtype _jc_gnu_java_security_provider_GnuDHPublicKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_GnuDHPublicKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_GnuDHPublicKey$class_object;

#endif	/* _JC_gnu_java_security_provider_GnuDHPublicKey_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/GnuDHPublicKey.h <==
// public class gnu.java.security.provider.GnuDHPublicKey

// class file dependencies
// @dep_class 9c1068654c7b96dd gnu_java_security_provider_GnuDHPublicKey
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_GnuDHPublicKey_H_
#define _JC_gnu_java_security_provider_GnuDHPublicKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_javax_crypto_spec_DHParameterSpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$sub_refs	_jc_gnu_java_security_provider_GnuDHPublicKey$sub_refs;
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$sub_nonrefs	_jc_gnu_java_security_provider_GnuDHPublicKey$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$refs	_jc_gnu_java_security_provider_GnuDHPublicKey$refs;
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$nonrefs	_jc_gnu_java_security_provider_GnuDHPublicKey$nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDHPublicKey$object	_jc_gnu_java_security_provider_GnuDHPublicKey$object;

typedef const struct _jc_gnu_java_security_provider_GnuDHPublicKey$vmethods	_jc_gnu_java_security_provider_GnuDHPublicKey$vmethods;
typedef const struct _jc_gnu_java_security_provider_GnuDHPublicKey$vtable	_jc_gnu_java_security_provider_GnuDHPublicKey$vtable;
typedef const struct _jc_gnu_java_security_provider_GnuDHPublicKey$vtype	_jc_gnu_java_security_provider_GnuDHPublicKey$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_GnuDHPublicKey$method$_init$7107c3e523ee96ea(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *, struct _jc_javax_crypto_spec_DHParameterSpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_crypto_spec_DHParameterSpec$object *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getParams$ce54829b76ac0d04(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuDHPublicKey$method$getY$e067a5f1fb934d2a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getParams$ce54829b76ac0d04;
extern _jc_method _jc_gnu_java_security_provider_GnuDHPublicKey$method_info$getY$e067a5f1fb934d2a;

// Virtual methods structure
struct _jc_gnu_java_security_provider_GnuDHPublicKey$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_javax_crypto_spec_DHParameterSpec$object	*(*getParams$ce54829b76ac0d04)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getY$e067a5f1fb934d2a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDHPublicKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_GnuDHPublicKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_GnuDHPublicKey$vmethods	gnu_java_security_provider_GnuDHPublicKey;
};

// Vtype
struct _jc_gnu_java_security_provider_GnuDHPublicKey$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_GnuDHPublicKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDHPublicKey$sub_refs {
	_jc_byte_array	*encoded;
	struct _jc_javax_crypto_spec_DHParameterSpec$object	*params;
	struct _jc_java_math_BigInteger$object	*Y;
	struct _jc_java_math_BigInteger$object	*q;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDHPublicKey$refs {
    _jc_gnu_java_security_provider_GnuDHPublicKey$sub_refs	gnu_java_security_provider_GnuDHPublicKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDHPublicKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDHPublicKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_GnuDHPublicKey$sub_nonrefs	gnu_java_security_provider_GnuDHPublicKey;
};

// Object instance structure
struct _jc_gnu_java_security_provider_GnuDHPublicKey$object {
	_jc_gnu_java_security_provider_GnuDHPublicKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_GnuDHPublicKey$vtype	*vtype;
	_jc_gnu_java_security_provider_GnuDHPublicKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_GnuDHPublicKey$vtype _jc_gnu_java_security_provider_GnuDHPublicKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_GnuDHPublicKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_GnuDHPublicKey$class_object;

#endif	/* _JC_gnu_java_security_provider_GnuDHPublicKey_H_ */
